.. _constituents_api:

Constituents
============

.. autosummary::
    :toctree: generated/

    sasktran2.constituent.Rayleigh
    sasktran2.constituent.VMRAltitudeAbsorber
    sasktran2.constituent.NumberDensityScatterer
    sasktran2.constituent.ExtinctionScatterer
    sasktran2.constituent.CollisionInducedAbsorber

.. _constituents_api_brdf:

BRDFs
-----
.. autosummary::
    :toctree: generated/

    sasktran2.constituent.LambertianSurface
    sasktran2.constituent.SnowKokhanovsky
    sasktran2.constituent.MODIS

Solar Irradiance Models
-----------------------
.. autosummary::
    :toctree: generated/

    sasktran2.constituent.SolarIrradiance

Emissions
---------
.. autosummary::
    :toctree: generated/

    sasktran2.constituent.ThermalEmission
    sasktran2.constituent.SurfaceThermalEmission

Dummy Constituents
------------------
.. autosummary::
    :toctree: generated/

    sasktran2.constituent.AirMassFactor
